***********
Likelihoods
***********

.. currentmodule:: glimix_core.lik

.. autosummary::
  :toctree: _autosummary
  :template: class.rst

  BernoulliProdLik
  BinomialProdLik
  DeltaProdLik
  PoissonProdLik
